<%!
from myfile import js,css
%>\
<link href="${css.my}" rel="stylesheet" type="text/css" />
<script src="http://ajax.googleapis.com/ajax/libs/jquery/1.3.2/jquery.min.js"></script>\
<script src="${js.my}"></script>\
<title>${html_title_wrap()}</title>\
<%def name="html_title_wrap()" filter="trim,html_title_filter">${self.html_title()}</%def>
<%def name="html_title_filter(txt)" filter="trim">
<%txt=txt.strip()%>
%if txt:
${txt}${" - stdyun.com"|n}
%else:
stdyun.com 标准云
%endif
</%def>
<%def name="html_title()"></%def>