#coding:utf-8

#是否启用在线调试
DEBUG = False

#是否启用Mako的自动检测模板更新
MAKO_FILESYSTEM_CHECK = False

#是否python由提供静态文件的服务
SERVER_STATIC_FILE = False

#是否使用原始的css，js
ORG_CSS_JS = True

#Javascript文件服务器的域名
JS_FILE_HOST = ""

#静态文件服务器的域名
FILE_HOST = ""

#数据库配置
WTREE_HOST = "localhost:3306:wtree:root:password"
