function msnoperate(c,b){var a=new Array();a={reghotmail:"http://go.discuz.com/?app=msn&linkid=1",reglivemail:"http://go.discuz.com/?app=msn&linkid=2",regliveid:"http://go.discuz.com/?app=msn&linkid=3",download:"http://go.discuz.com/?app=msn&linkid=4",add:"http://go.discuz.com/?app=msn&linkid=5&msn="+b,chat:"http://go.discuz.com/?app=msn&linkid=6&msn="+b};if(messengerInstalled()){window.open(a[c])}else{window.open("http://go.discuz.com/msn/msn.html","_blank","width=571, height=498")}}function messengerInstalled(){try{new ActiveXObject("MSNMessenger.P4QuickLaunch");return true}catch(a){return false}};