p,html,body,div,span,applet,object,iframe,h1,h2,h3,h4,h5,h6,blockquote,pre,a,abbr,acronym,address,big,cite,code,del,dfn,em,font,img,ins,kbd,q,s,samp,small,strike,strong,sub,sup,tt,var,u,i,center,dl,dt,dd,ol,fieldset,form,label,legend,table,caption,tbody,tfoot,thead,tr,th,td{margin:0;padding:0;border:0;font-family:宋体;font-size:100%;vertical-align:baseline;background:transparent;font-weight:normal;}textarea{background:#fff;overflow:auto;font-family:新宋体,宋体,Simsun;font-size:16px;border:1px solid #ccc;}body{background:#fff;}span,div{cursor:default;}strong,em,optgroup{font-style:normal;font-weight:bold;}optgroup{color:#566;text-align:center;}em{color:#931;}body{line-height:1;}ol,ul{list-style:none;}blockquote,q{quotes:none;}blockquote:before,blockquote:after,q:before,q:after{content:'';content:none;}ins{text-decoration:none;}del{text-decoration:line-through;}table{border-collapse:collapse;border-spacing:0;}pre{white-space:pre-wrap;word-wrap:break-word;}input{padding:3px;font-size:16px;}input:focus{outline:1px solid #acf;}p{line-height:1.8;}div{line-height:22px;}form a{color:#13c;}a{color:#3267B9;text-decoration:none;}a:hover{color:#F60;text-decoration:underline;}.R{float:right;}.L{float:left;}.CL:after{content:"\0020";display:block;height:0;clear:both;}.CL{_height:1em;min-height:1px;}.L14 #WRP{float:left;width:100%;}.L14 #CNT{margin:0 340px 0 200px;}.L14 #NAV{float:left;width:340px;margin-left:-340px;}.L14 #EXT{float:left;width:200px;margin-left:-100%;}.L14 #FOT{clear:left;width:100%;}.Pform{margin:40px auto 0;width:335px;}.Bform select{font-size:16px;margin-left:-6px;}.Bform .Err,.Bform span{display:block;margin-top:5px;font-size:14px;color:#666;text-align:left;margin-left:38px;}.Bform p label{margin-right:10px;}.Bform p input{width:286px;}.Bform p{margin-bottom:20px;font-size:14px;}.Bform .Err,.Err{padding-bottom:2px;font-size:12px;margin-top:0;color:#d30;}.Err{display:block;}.Warn{color:#d30;}.Ok{color:#090;}.HideErr .Err{display:none;}.Bbtn{font-size:16px;padding:3px 6px;}#Nav{border-bottom:1px dotted #CCC;margin:0;padding:0;}#Nav a{border:1px solid #FFF;color:#332;margin-left:8px;margin-top:4px;padding:4px 8px 3px;}#Nav a:visited{color:#430;}#Nav a:hover{text-decoration:none;border-color:#e3e3e3;}#Nav .CL{margin:15px auto 6px;width:90%;}#Nav #ksLogo{padding:0;margin:0 20px 0 0;width:121px;height:41px;float:left;border:0;outline:0;}